"""From the dumped list of student data generate a list with essential data."""

import argparse
import logging

from course_utilities.id_generation import hashing
from course_utilities.id_generation import mail
from course_utilities.id_generation import nbgrader
from course_utilities.id_generation import studip


def main(cli_args):
    logging.debug(f'Read in students table from {cli_args.student_file}')
    student_data = studip.import_csv(cli_args.student_file)

    logging.info(
        f'Generate hashes of length {cli_args.length} with salt {cli_args.salt}'
    )
    student_data['hash'] = hashing.create_hashes(
        student_data, cli_args.salt, cli_args.length
    )

    logging.info(f'Write mail data to {cli_args.mailfile}')
    mail.write_mail_table(cli_args.mailfile, student_data)

    logging.info(f'Write file for nbgrader import to {cli_args.mailfile}')
    nbgrader.write_nbgrader_import(cli_args.nbgrader_import_file, student_data)

    logging.info(
        f'Write dictionary for nbgrader collection to {cli_args.mailfile}'
    )
    nbgrader.write_students_dict(cli_args.nbgrader_students_dict, student_data)


if __name__ == '__main__':
    import course_utilities.utils.command_line as command_line
    from course_utilities.utils.cli_args import ID_GENERATION

    logging.basicConfig(level=logging.DEBUG)
    parsed_cli_args = command_line.parse_command_line_args(ID_GENERATION)
    main(parsed_cli_args)
